## 2.5.0.20250701 (2025-07-01)

[stubsabot] Bump lupa to 2.5.* (#14279)

Co-authored-by: stubsabot <>

## 2.4.0.20250112 (2025-01-12)

[stubsabot] Bump lupa to 2.4.* (#13391)

Co-authored-by: stubsabot <>

## 2.3.0.20250111 (2025-01-11)

[stubsabot] Bump lupa to 2.3.* (#13383)

Release: https://pypi.org/pypi/lupa/2.3
Homepage: https://github.com/scoder/lupa
Repository: https://github.com/scoder/lupa
Typeshed stubs: https://github.com/python/typeshed/tree/main/stubs/lupa

## 2.2.0.20240917 (2024-09-17)

Add lupa stubs (#12650)

